@@ -56,6 +56,40 @@ def list_tables(cur, arg=None, arg_type=PARSED_QUERY, verbose=False):
     return [(None, tables, headers, status)]
 
 
+@special_command(
+    ".views",
+    "\\dv",
+    "List views.",
+    arg_type=PARSED_QUERY,
+    case_sensitive=True,
+    aliases=("\\dv",),
+)
+def list_views(cur, arg=None, arg_type=PARSED_QUERY, verbose=False):
+    if arg:
+        args = ("{0}%".format(arg),)
+        query = """
+            SELECT name FROM sqlite_master
+            WHERE type = 'view' AND name LIKE ? AND name NOT LIKE 'sqlite_%'
+            ORDER BY 1
+        """
+    else:
+        args = tuple()
+        query = """
+            SELECT name FROM sqlite_master
+            WHERE type = 'view' AND name NOT LIKE 'sqlite_%'
+            ORDER BY 1
+        """
+    log.debug(query)
+    cur.execute(query, args)
+    views = cur.fetchall()
+    status = ""
+    if cur.description:
+        headers = [x[0] for x in cur.description]
+    else:
+        return [(None, None, None, "")]
+    return [(None, views, headers, status)]
+
+
 @special_command(
     ".schema",
     ".schema[+] [table]",
@@ -68,7 +102,7 @@ def show_schema(cur, arg=None, **_):
         args = (arg,)
         query = """
             SELECT sql FROM sqlite_master
-            WHERE name==? AND sql IS NOT NULL
+            WHERE tbl_name==? AND sql IS NOT NULL
             ORDER BY tbl_name, type DESC, name
         """
     else:
@@ -90,7 +124,6 @@ def show_schema(cur, arg=None, **_):
 
     return [(None, tables, headers, status)]
 
-
 @special_command(
     ".databases",
     ".databases",
@@ -109,7 +142,6 @@ def list_databases(cur, **_):
     else:
         return [(None, None, None, "")]
 
-
 @special_command(
     ".indexes",
     ".indexes [tablename]",
@@ -122,14 +154,14 @@ def list_indexes(cur, arg=None, arg_type=PARSED_QUERY, verbose=False):
     if arg:
         args = ("{0}%".format(arg),)
         query = """
-            SELECT name FROM sqlite_master
+            SELECT name, sql FROM sqlite_master
             WHERE type = 'index' AND tbl_name LIKE ? AND name NOT LIKE 'sqlite_%'
             ORDER BY 1
         """
     else:
         args = tuple()
         query = """
-            SELECT name FROM sqlite_master
+            SELECT name, sql FROM sqlite_master
             WHERE type = 'index' AND name NOT LIKE 'sqlite_%'
             ORDER BY 1
         """
