@@ -7,6 +7,7 @@ import shlex
 import sys
 from runpy import run_module
 from typing import Optional, Tuple
+from time import time
 
 import click
 
@@ -19,6 +20,8 @@ try:
 except ImportError:
     llm = None
     cli = None
+    LLM_CLI_COMMANDS = []
+    MODELS = {}
 
 from . import export
 from .main import parse_special_command
@@ -191,9 +194,8 @@ def ensure_litecli_template(replace=False):
     run_external_cmd("llm", PROMPT, "--save", "litecli")
     return
 
-
 @export
-def handle_llm(text, cur) -> Tuple[str, Optional[str]]:
+def handle_llm(text, cur) -> Tuple[str, Optional[str], float]:
     """This function handles the special command `\\llm`.
 
     If it deals with a question that results in a SQL query then it will return
@@ -222,7 +224,7 @@ def handle_llm(text, cur) -> Tuple[str, Optional[str]]:
     if "-c" in parts:
         capture_output = True
         use_context = False
-    # If the parts has `pormpt` command without `-c` then use context to the prompt.
+    # If the parts has `prompt` command without `-c` then use context to the prompt.
     # \llm -m ollama prompt "Most visited urls?"
     elif "prompt" in parts:  # User might invoke prompt with an option flag in the first argument.
         capture_output = True
@@ -236,6 +238,10 @@ def handle_llm(text, cur) -> Tuple[str, Optional[str]]:
     elif parts[0] in LLM_CLI_COMMANDS:
         capture_output = False
         use_context = False
+    # If the user wants to use --help option to see each command and it's description
+    elif "--help" == parts[0]:
+        capture_output = False
+        use_context = False
     # If the parts doesn't have any known LLM_CLI_COMMANDS then the user is
     # invoking a question. eg: \llm -m ollama "Most visited urls?"
     elif not set(parts).intersection(LLM_CLI_COMMANDS):
@@ -250,7 +256,10 @@ def handle_llm(text, cur) -> Tuple[str, Optional[str]]:
     if not use_context:
         args = parts
         if capture_output:
+            click.echo("Calling llm command")
+            start = time()
             _, result = run_external_cmd("llm", *args, capture_output=capture_output)
+            end = time()
             match = re.search(_SQL_CODE_FENCE, result, re.DOTALL)
             if match:
                 sql = match.group(1).strip()
@@ -258,17 +267,21 @@ def handle_llm(text, cur) -> Tuple[str, Optional[str]]:
                 output = [(None, None, None, result)]
                 raise FinishIteration(output)
 
-            return result if verbose else "", sql
+            return result if verbose else "", sql, end - start
         else:
             run_external_cmd("llm", *args, restart_cli=restart)
             raise FinishIteration(None)
 
     try:
         ensure_litecli_template()
+        # Measure end to end llm command invocation.
+        # This measures the internal DB command to pull the schema and llm command
+        start = time()
         context, sql = sql_using_llm(cur=cur, question=arg, verbose=verbose)
+        end = time()
         if not verbose:
             context = ""
-        return context, sql
+        return context, sql, end - start
     except Exception as e:
         # Something went wrong. Raise an exception and bail.
         raise RuntimeError(e)
@@ -297,6 +310,7 @@ def sql_using_llm(cur, question=None, verbose=False) -> Tuple[str, Optional[str]
             WHERE type IN ('table','view') AND name NOT LIKE 'sqlite_%'
             ORDER BY 1
     """
+    click.echo("Preparing schema information to feed the llm")
     sample_row_query = "SELECT * FROM {table} LIMIT 1"
     log.debug(schema_query)
     cur.execute(schema_query)
@@ -328,7 +342,9 @@ def sql_using_llm(cur, question=None, verbose=False) -> Tuple[str, Optional[str]
         question,
         " ",  # Dummy argument to prevent llm from waiting on stdin
     ]
+    click.echo("Invoking llm command with schema information")
     _, result = run_external_cmd("llm", *args, capture_output=True)
+    click.echo("Received response from the llm command")
     match = re.search(_SQL_CODE_FENCE, result, re.DOTALL)
     if match:
         sql = match.group(1).strip()
