@@ -258,7 +258,7 @@ class SQLCompleter(Completer):
         self.reserved_words = set()
         for x in self.keywords:
             self.reserved_words.update(x.split())
-        self.name_pattern = compile(r"^[_a-z][_a-z0-9\$]*$")
+        self.name_pattern = compile(r"^[_a-zA-Z][_a-zA-Z0-9\$]*$")
 
         self.special_commands = []
         self.table_formats = supported_formats
@@ -320,6 +320,7 @@ class SQLCompleter(Completer):
         try:
             data = [self.escaped_names(d) for d in data]
         except Exception:
+            _logger.exception("Failed to get relation names.")
             data = []
 
         # dbmetadata['tables'][$schema_name][$table_name] should be a list of
@@ -351,6 +352,7 @@ class SQLCompleter(Completer):
         try:
             column_data = [self.escaped_names(d) for d in column_data]
         except Exception:
+            _logger.exception("Failed to get column names.")
             column_data = []
 
         metadata = self.dbmetadata[kind]
@@ -366,6 +368,7 @@ class SQLCompleter(Completer):
         try:
             func_data = [self.escaped_names(d) for d in func_data]
         except Exception:
+            _logger.exception("Failed to get function names.")
             func_data = []
 
         # dbmetadata['functions'][$schema_name][$function_name] should return
